==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgoutputwindow.cpp <==
//
// C++ Implementation: dlgoutputwindow
//
// Description: 
//
//
// Author: Vladimir Lazarenko <vlad@lazarenko.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "../dialogs/dlgoutputwindow.h"
#include "../cconsole.h"
#include "../csession.h"
#include "../kmuddy.h"

#include <klocale.h>
#include <kdialogbase.h>
#include <kdeversion.h>

#if KDE_IS_VERSION(3,2,0)
#include <kwin.h>
#endif 

#include <netwm_def.h>
#include <qlayout.h>

extern KMuddy *kmuddy;

dlgOutputWindow::dlgOutputWindow(QWidget *parent, const char *name)
 : KDialogBase(parent, name, false, i18n ("Output window"), 0)
{
  //initial size
  setInitialSize (QSize (250, 300));

  //main widget
  QWidget *page = new QWidget (this);
  QVBoxLayout *layout = new QVBoxLayout (page);
  
  setMainWidget (page);
  setFocusPolicy (QWidget::StrongFocus);

  owindow = new cConsole(true, page);
  //our window shall also have a status bar
  owindow->setVScrollBarMode (QScrollView::AlwaysOn);

  //no session information yet, will set it when it's available
  sess = 0;
  owindow->setSession (0);

  KDialog::resizeLayout (this, 0, 5);
  
#if KDE_IS_VERSION(3,2,0)
  KWin::setType(this->winId(), NET::Utility);
#endif

  layout->setMargin (0);
  layout->addWidget(owindow);
}

dlgOutputWindow::~dlgOutputWindow()
{
}

void dlgOutputWindow::setSession (cSession *s)
{
  sess = s;
  //also inform console about the new session
  owindow->setSession (sess);
}

void dlgOutputWindow::addLine (cTextChunk *chunk)
{
  if (owindow)
    owindow->addLine (chunk);
}

void dlgOutputWindow::setOutputWindowName(const QString &name)
{
  if(name)
    this->setCaption(name);
}

void dlgOutputWindow::setFont(QFont font)
{
  owindow->setFont(font);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgoutputwindow.cpp <==
//
// C++ Implementation: dlgoutputwindow
//
// Description: 
//
//
// Author: Vladimir Lazarenko <vlad@lazarenko.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "dlgoutputwindow.h"
#include "cconsole.h"

#include <klocale.h>
#include <kdialogbase.h>
#include <kdeversion.h>

#if KDE_IS_VERSION(3,2,0)
#include <kwin.h>
#endif 

#include <netwm_def.h>
#include <qlayout.h>

dlgOutputWindow::dlgOutputWindow (QWidget *parent, const char *name)
 : KDialogBase(parent, name, false, i18n ("Output window"), 0)
{
  //initial size
  setInitialSize (QSize (250, 300));

  //main widget
  QWidget *page = new QWidget (this);
  QVBoxLayout *layout = new QVBoxLayout (page);
  
  setMainWidget (page);
  setFocusPolicy (QWidget::StrongFocus);

  owindow = new cConsole(true, page);
  //our window shall also have a status bar
  owindow->setVScrollBarMode (QScrollView::AlwaysOn);

  //no session information yet, will set it when it's available
  sess = 0;
  owindow->setSession (0);

  KDialog::resizeLayout (this, 0, 5);
  
#if KDE_IS_VERSION(3,2,0)
  KWin::setType(this->winId(), NET::Utility);
#endif

  layout->setMargin (0);
  layout->addWidget(owindow);
}

dlgOutputWindow::~dlgOutputWindow()
{
}

void dlgOutputWindow::setSession (int _sess)
{
  sess = _sess;
  //also inform console about the new session
  owindow->setSession (sess);
}

void dlgOutputWindow::addLine (cTextChunk *chunk)
{
  if (owindow)
    owindow->addLine (chunk);
}

void dlgOutputWindow::setOutputWindowName(const QString &name)
{
  if(name)
    this->setCaption(name);
}

void dlgOutputWindow::setFont(QFont font)
{
  owindow->setFont(font);
}
